File I/O through ``nddata.CCDData`` uses the Unified I/O interface, which has
added support for reading and writing file paths of the form ``~/file.csv`` or
``~<username>/file.csv``, referring to the home directory of the current user
or the specified user, respectively.
